@@ -9,7 +9,7 @@ require Exporter;
 
 our @ISA = qw(Exporter);
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 
 sub new {
@@ -35,6 +35,12 @@ sub moveTo {
     croak("Expected $self->{numDims} coordinates, but ".scalar(@{$opts{coords}})." given");
   }
 
+  if (defined($self->{lastTime}) &&
+      $time < $self->{lastTime}) {
+    carp("Item can't be moved to time in the past.  Previous time moved: $self->{lastTime}.  Current movement time: $time");
+    return;
+  }
+
   if (defined($self->{lastCoords})) {
     $self->{rt}->dec($time, weight => $self->{weight}, coords => $self->{lastCoords});
   }
